aboutsummaryrefslogtreecommitdiff
path: root/google/ads/googleads/v1/resources/geo_target_constant.proto
diff options
context:
space:
mode:
Diffstat (limited to 'google/ads/googleads/v1/resources/geo_target_constant.proto')
-rw-r--r--google/ads/googleads/v1/resources/geo_target_constant.proto4
1 files changed, 2 insertions, 2 deletions
diff --git a/google/ads/googleads/v1/resources/geo_target_constant.proto b/google/ads/googleads/v1/resources/geo_target_constant.proto
index c0ff9aa9e..6da966027 100644
--- a/google/ads/googleads/v1/resources/geo_target_constant.proto
+++ b/google/ads/googleads/v1/resources/geo_target_constant.proto
@@ -40,12 +40,12 @@ message GeoTargetConstant {
pattern: "geoTargetConstants/{geo_target_constant}"
};
// Immutable. The resource name of the geo target constant.
// Geo target constant resource names have the form:
//
// `geoTargetConstants/{geo_target_constant_id}`
string resource_name = 1 [
- (google.api.field_behavior) = IMMUTABLE,
+ (google.api.field_behavior) = OUTPUT_ONLY,
(google.api.resource_reference) = {
type: "googleads.googleapis.com/GeoTargetConstant"
}
@@ -40,12 +40,12 @@ message GeoTargetConstant {
pattern: "geoTargetConstants/{geo_target_constant}"
};
- // Immutable. The resource name of the geo target constant.
+ // Output only. The resource name of the geo target constant.
// Geo target constant resource names have the form:
//